==> dde-introduction_5.6.35.orig.tar.xz: dde-introduction-5.6.35/translations/dde-introduction_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>Społeczność</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>Informacje zwrotne</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>Podziękowania</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Wybierz tryb pulpitu</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Możesz przełączać tryby, klikając prawym przyciskiem myszy stację dokującą</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Wybierz tryb pracy</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>Możesz to zmienić w Centrum sterowania &gt; Personalizacja &gt; Efekt okna</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Wybierz motyw ikony</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Zmień to w Centrum sterowania &gt; Personalizacja &gt; Motyw ikon</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>Wprowadzenie</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>Witamy</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>Tryb pulpitu</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Wybierz tryb pulpitu</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Możesz przełączać tryby, klikając prawym przyciskiem myszy stację dokującą</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>Tryb pracy</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Wybierz tryb pracy</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>Wybierz tryb normalny, jeśli masz komputer o niskiej wydajności</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>Motyw ikon</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Wybierz motyw ikony</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Zmień to w Centrum sterowania &gt; Personalizacja &gt; Motyw ikon</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>Witamy</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>Tryb normalny</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>Tryb efektowny</translation>
    </message>
</context>
</TS>

==> dde-introduction_5.6.38.orig.tar.xz: dde-introduction-5.6.38/translations/dde-introduction_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>Społeczność</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>Opinia użytkownika</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>Podziękowania</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Wybierz tryb pulpitu</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Przełączaj się między trybami klikając prawym przyciskiem na dok</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Wybierz tryb pracy</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>Możesz to zmienić w Centrum kontroli &gt; Personalizacja &gt; Efekt okna</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Wybierz motyw ikony</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Możesz to zmienić w Centrum kontroli &gt; Personalizacja &gt; Motyw ikon</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>Wprowadzenie</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>Witamy</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>Tryb pulpitu</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Wybierz tryb pulpitu</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Przełączaj się między trybami klikając prawym przyciskiem na dok</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>Tryb pracy</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Wybierz tryb pracy</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>Wybierz tryb normalny, jeśli posiadasz komputer o niskiej wydajności</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>Motyw ikon</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Wybierz motyw ikony</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Możesz to zmienić w Centrum kontroli &gt; Personalizacja &gt; Motyw ikon</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>Witamy</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>Tryb normalny</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>Tryb efektów</translation>
    </message>
</context>
</TS>
